# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

ENVIRONMENT_VARIABLES = [
    "TRAVIS_BRANCH",
    "TRAVIS_BUILD_ID",
    "TRAVIS_BUILD_NUMBER",
    "TRAVIS_COMMIT",
    "TRAVIS_COMMIT_MESSAGE",
    "TRAVIS_COMMIT_RANGE",
    "TRAVIS_EVENT_TYPE",
    "TRAVIS_JOB_ID",
    "TRAVIS_JOB_NUMBER",
    "TRAVIS_OS_NAME",
    "TRAVIS_PULL_REQUEST",
    "TRAVIS_PULL_REQUEST_BRANCH",
    "TRAVIS_PULL_REQUEST_SHA",
    "TRAVIS_PULL_REQUEST_SLUG",
    "TRAVIS_REPO_SLUG",
    "TRAVIS_SUDO",
    "TRAVIS_TAG",
]
